==> tuia-commercial-center-api-1.0.17-CD-20191208.062922-6-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/finance/FarmFinanceConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm.finance;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class FarmFinanceConfigDto implements Serializable {

    private static final long serialVersionUID = -379660533572431902L;

    private Long id;

    private Long appId;

    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Long budget;

    // 新增预算，单位分
    private Long addBudget;

    // 冻结的预算，单位分
    private Long frozenBudget;

    /*总预算*/
    private Long totalBudget;

    private BigDecimal constantC;

    private BigDecimal constantA;

    private BigDecimal constantPercent;

    private BigDecimal constantP;

    private Integer dayFixedRedPacketNum;

    // 提现门槛单位分
    private Long withdrawThreshold;

    // 预警门槛百分比
    private BigDecimal alarmThreshold;

    // 临界门槛百分比
    private BigDecimal limitThreshold;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Long getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Long frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public BigDecimal getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(BigDecimal alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public BigDecimal getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(BigDecimal limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getTotalBudget() {
        return totalBudget;
    }

    public void setTotalBudget(Long totalBudget) {
        this.totalBudget = totalBudget;
    }

    public Long getAddBudget() {
        return addBudget;
    }

    public void setAddBudget(Long addBudget) {
        this.addBudget = addBudget;
    }

    public BigDecimal getConstantC() {
        return constantC;
    }

    public void setConstantC(BigDecimal constantC) {
        this.constantC = constantC;
    }

    public BigDecimal getConstantA() {
        return constantA;
    }

    public void setConstantA(BigDecimal constantA) {
        this.constantA = constantA;
    }

    public BigDecimal getConstantPercent() {
        return constantPercent;
    }

    public void setConstantPercent(BigDecimal constantPercent) {
        this.constantPercent = constantPercent;
    }

    public BigDecimal getConstantP() {
        return constantP;
    }

    public void setConstantP(BigDecimal constantP) {
        this.constantP = constantP;
    }

    public Integer getDayFixedRedPacketNum() {
        return dayFixedRedPacketNum;
    }

    public void setDayFixedRedPacketNum(Integer dayFixedRedPacketNum) {
        this.dayFixedRedPacketNum = dayFixedRedPacketNum;
    }
}

==> tuia-commercial-center-api-1.0.18-CD-20191203.082701-1-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/farm/finance/FarmFinanceConfigDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.farm.finance;

import java.io.Serializable;
import java.util.Date;

public class FarmFinanceConfigDto implements Serializable {

    private static final long serialVersionUID = -379660533572431902L;

    private Long id;

    private Long appId;

    // 阶段(从1开始，第几周期
    private Integer stage;

    // 周期天数
    private Integer period;

    // 预算，单位分
    private Long budget;

    // 新增预算，单位分
    private Long addBudget;

    // 冻结的预算，单位分
    private Long frozenBudget;

    /*总预算*/
    private Long totalBudget;

    // 提现门槛单位分
    private Long withdrawThreshold;

    // 预警门槛百分比
    private Double alarmThreshold;

    // 临界门槛百分比
    private Double limitThreshold;

    //阶梯状态 1、显示 2、隐藏
    private Integer configStatus;

    // 创建时间
    private Date gmtCreate;

    // 修改时间
    private Date gmtModified;

    public Integer getConfigStatus() {
        return configStatus;
    }

    public void setConfigStatus(Integer configStatus) {
        this.configStatus = configStatus;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getPeriod() {
        return period;
    }

    public void setPeriod(Integer period) {
        this.period = period;
    }

    public Long getBudget() {
        return budget;
    }

    public void setBudget(Long budget) {
        this.budget = budget;
    }

    public Long getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Long frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public Double getAlarmThreshold() {
        return alarmThreshold;
    }

    public void setAlarmThreshold(Double alarmThreshold) {
        this.alarmThreshold = alarmThreshold;
    }

    public Double getLimitThreshold() {
        return limitThreshold;
    }

    public void setLimitThreshold(Double limitThreshold) {
        this.limitThreshold = limitThreshold;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getTotalBudget() {
        return totalBudget;
    }

    public void setTotalBudget(Long totalBudget) {
        this.totalBudget = totalBudget;
    }

    public Long getAddBudget() {
        return addBudget;
    }

    public void setAddBudget(Long addBudget) {
        this.addBudget = addBudget;
    }

}
